@@ -194,6 +194,8 @@ class AutoAI(BaseExperiment):
                   fairness_info: dict = None,
                   sampling_type: 'SamplingTypes' = None,
                   sample_size_limit: int = None,
+                  sample_rows_limit: int = None,
+                  sample_percentage_limit: float = None,
                   n_parallel_data_connections: int = None,
                   number_of_batch_rows: int = None,
                   categorical_imputation_strategy: ImputationStrategy = None,
@@ -395,6 +397,14 @@ class AutoAI(BaseExperiment):
             The size of sample upper bound (in bytes). The default value is 1GB.
             Supported only for IBM Cloud Pak® for Data 4.5 and above.
 
+        sample_rows_limit: int, optional
+            The size of sample upper bound (in rows).
+            Supported only for IBM Cloud Pak® for Data 4.6 and above.
+
+        sample_percentage_limit: float, optional
+            The size of sample upper bound (as fraction of dataset size).
+            Supported only for IBM Cloud Pak® for Data 4.6 and above.
+
         number_of_batch_rows: int, optional
             Number of rows to read in each batch when reading from flight connection.
 
@@ -517,6 +527,24 @@ class AutoAI(BaseExperiment):
                 include_only_estimators = daub_include_only_estimators
             daub_include_only_estimators = None
 
+        if train_sample_rows_test_size and self._workspace.wml_client.ICP_46:
+            print('Note: Using `train_sample_rows_test_size` is deprecated.'
+                  'Use either `sample_rows_limit` or `sample_percentage_limit` instead.')
+            if not sample_rows_limit and not sample_percentage_limit:
+                if type(train_sample_rows_test_size) is float and train_sample_rows_test_size <= 1:
+                    print('Value of `train_sample_rows_test_size` parameter'
+                          'will be passed as `sample_percentage_limit`.')
+                    sample_percentage_limit = train_sample_rows_test_size
+                elif int(train_sample_rows_test_size) == train_sample_rows_test_size and train_sample_rows_test_size > 1:
+                    print('Value of `train_sample_rows_test_size` parameter'
+                          'will be passed as `sample_rows_limit`.')
+                    sample_rows_limit = int(train_sample_rows_test_size)
+                train_sample_rows_test_size = None
+            elif sample_rows_limit or sample_percentage_limit:
+                print('Parameter `train_sample_rows_test_size` will be ignored.')
+                train_sample_rows_test_size = None
+
+
         def translate_str_imputation_param(x):
             if type(x) is list and prediction_type != PredictionType.FORECASTING:
                 raise ImputationListNotSupported()
@@ -660,6 +688,8 @@ class AutoAI(BaseExperiment):
                 fairness_info=fairness_info,
                 sampling_type=sampling_type,
                 sample_size_limit=sample_size_limit,
+                sample_rows_limit=sample_rows_limit,
+                sample_percentage_limit=sample_percentage_limit,
                 number_of_batch_rows=number_of_batch_rows,
                 n_parallel_data_connections=n_parallel_data_connections,
                 categorical_imputation_strategy=categorical_imputation_strategy,
