@@ -56,6 +56,12 @@ class BaseAutoPipelines:
         """Get particular computed Pipeline"""
         pass
 
+    def get_pipeline_notebook(self,
+                     pipeline_name: str = None,
+                     persist: 'bool' = False) -> Union['Pipeline', 'TrainablePipeline']:
+        """Get particular computed pipeline notebook"""
+        pass
+
     @abstractmethod
     def predict(self, X: Union['DataFrame', 'ndarray']) -> 'ndarray':
         """Use predict on top of the computed pipeline."""
