@@ -161,6 +161,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  test_data_encoding: str = 'utf-8',
                  sampling_type=None,
                  sample_size_limit=None,
+                 sample_rows_limit=None,
+                 sample_percentage_limit=None,
                  number_of_batch_rows=None,
                  categorical_imputation_strategy=None,
                  numerical_imputation_strategy=None,
@@ -218,6 +220,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'text_columns_names': text_columns_names,
             'sampling_type': sampling_type,
             'sample_size_limit': sample_size_limit,
+            'sample_rows_limit': sample_rows_limit,
+            'sample_percentage_limit': sample_percentage_limit,
             'number_of_batch_rows': number_of_batch_rows,
             'n_parallel_data_connections': n_parallel_data_connections,
             'test_data_csv_separator': test_data_csv_separator,
