@@ -1012,10 +1012,10 @@ class FlightConnection:
                 logger.debug(f"LB: Mini batch number: {mini_batch_counter}")
 
             except queue.Empty:
-                if data is None or data.empty:   # raise the error only if any data were not downloaded.
+                if data is None or isinstance(data, int) or data.empty:   # raise the error only if any data were not downloaded.
                     raise DataStreamError(
                         reason=f'LB: No data were downloaded in the thread due to timeout on '
-                               f'waiting for data batch: max {timeout / 60} minutes.')
+                               f'waiting for data batch: max {timeout / 60} minutes, data: {data}')
 
             logical_batch.append(data.iloc[:max_rows])
             not_used_data = data.iloc[max_rows:]
@@ -1039,7 +1039,7 @@ class FlightConnection:
                 if max_rows < 0:  # finish if limit has been reached
                     break
 
-    def _select_source_command(self, infer_schema: bool = True) -> List[str]:
+    def _select_source_command(self, infer_schema: bool = False) -> List[str]:
         """Based on a data source type, select appropriate commands for flight service configuration."""
 
         infer_schema = infer_schema
