@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 from ibm_watson_machine_learning.utils import STR_TYPE, get_url, docstring_parameter, STR_TYPE_NAME, print_text_header_h2, print_text_header_h1, str_type_conv, meta_props_str_conv, StatusLogger
 from ibm_watson_machine_learning.metanames import LearningSystemMetaNames
