@@ -289,7 +289,7 @@ class Repository(WMLResource):
         return self._client.pipelines.store(meta_props)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def store_model(self, model, meta_props=None, training_data=None, training_target=None, pipeline=None, feature_names=None, label_column_names=None,subtrainingId=None, round_number=None):
+    def store_model(self, model, meta_props=None, training_data=None, training_target=None, pipeline=None, feature_names=None, label_column_names=None,subtrainingId=None, round_number=None, experiment_metadata=None):
         """
                 Create a model.
 
@@ -341,8 +341,6 @@ class Repository(WMLResource):
                     #. **round_number**: round number of a Federated Learning experiment that has been configured to save intermediate models.  This applies when model is a training id.  
                        **type**: int
 
-
-
                 **Output**
 
                 .. important::
@@ -411,7 +409,7 @@ class Repository(WMLResource):
                     >>> stored_model_details = client.repository.store_model(trained_model_guid, meta_props=metadata, training_data=None)
             """
 
-        return self._client._models.store(model, meta_props=meta_props, training_data=training_data, training_target=training_target, pipeline=pipeline, feature_names=feature_names, label_column_names=label_column_names,subtrainingId=subtrainingId,round_number=round_number)
+        return self._client._models.store(model, meta_props=meta_props, training_data=training_data, training_target=training_target, pipeline=pipeline, feature_names=feature_names, label_column_names=label_column_names,subtrainingId=subtrainingId,round_number=round_number,experiment_metadata=experiment_metadata)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def clone(self, artifact_id, space_id=None, action="copy", rev_id=None):
