@@ -204,15 +204,20 @@ class Script(WMLResource):
             sw_spec_details = self._client.software_specifications.get_details(script_meta[u'software_spec_uid'])
 
             if lang == 'R':
+                if self._client.ICP_46:
+                    rscript_sw_specs = ('runtime-22.2-r4.2',)
+                else:
+                    rscript_sw_specs = ('default_r3.6', 'runtime-22.1-r3.6',)
                 rscript_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
-                                       for sw_name in ('default_r3.6', 'runtime-22.1-r3.6')]
+                                       for sw_name in rscript_sw_specs]
 
                 if script_meta[u'software_spec_uid'] not in rscript_sw_spec_ids:
-                    raise WMLClientError("For R scripts, only base software specs 'default_r3.6', 'runtime-22.1-r3.6' "
+                    raise WMLClientError(f"For R scripts, only base software specs {','.join(rscript_sw_specs)} "
                                          "are supported. Specify "
                                          "the id you get via "
                                          "self._client.software_specifications.get_id_by_name(sw_name)")
 
+
             if(sw_spec_details[u'entity'][u'software_specification'][u'type'] == 'base'):
                 if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                     asset_meta = {
