@@ -113,7 +113,7 @@ class Shiny(WMLResource):
             client=self._client
         )
 
-        response = self._create_asset(shiny_meta['metadata'], file_path)
+        response = self._create_asset(shiny_meta, file_path)
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             return response
@@ -128,12 +128,29 @@ class Shiny(WMLResource):
     def _create_asset(self, shiny_meta, file_path):
 
         ##Step1: Create a shiny asset
-        name = shiny_meta[u'name']
+        name = shiny_meta['metadata'][u'name']
 
-        if shiny_meta.get('description') is not None:
-            desc = shiny_meta[u'description']
+        desc = ""
+        if shiny_meta['metadata'].get('description'):
+            desc = shiny_meta['metadata'][u'description']
+
+        shiny_sw_spec_id = None
+        if shiny_meta.get('software_spec_uid'):
+            shiny_sw_spec_id = shiny_meta[u'software_spec_uid']
+
+        if self._client.ICP_46:
+            shiny_sw_specs = ('rstudio_r4.2',)
         else:
-            desc = ""
+            shiny_sw_specs = ('shiny-r3.6',)
+        shiny_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
+                               for sw_name in shiny_sw_specs]
+
+        if shiny_sw_spec_id and shiny_sw_spec_id not in shiny_sw_spec_ids:
+            raise WMLClientError(
+                f"For R Shiny assets, only base software specs {','.join(shiny_sw_specs)} "
+                "are supported. Specify "
+                "the id you get via "
+                "self._client.software_specifications.get_id_by_name(sw_name)")
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             asset_meta = {
@@ -155,11 +172,15 @@ class Shiny(WMLResource):
                     "asset_category": "USER"
                 },
                  "entity": {
-                       "shiny_asset": {
-                             "ml_version": "4.0.0"
+                    "shiny_asset": {
+                        "ml_version": "4.0.0"
                      }
                  }
             }
+            if self._client.ICP_46 and shiny_sw_spec_id:
+                asset_meta['entity']['shiny_asset']['software_spec'] = \
+                    {"base_id": shiny_sw_spec_id}
+
 
         base_shiny_asset = {
             "fields": [
