@@ -166,7 +166,9 @@ class Training(WMLResource):
             details = self._get_artifact_details(url, training_uid, limit, 'trained models')
 
             if not _internal and details.get('entity', {}).get('status', {}).get('feature_engineering_components', {}).get('obm'):
-                if self._client.ICP:
+                if self._client.ICP_46:
+                    raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
+                elif self._client.ICP:
                     print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
                 #else:
                 #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
