@@ -771,3 +771,7 @@ def modify_details_for_script_and_shiny(details_from_get: dict) -> dict:
         pass
 
     return details_from_get
+
+
+def is_lale_pipeline(pipeline):
+    return type(pipeline).__module__ == 'lale.operators' and type(pipeline).__qualname__ == 'TrainedPipeline'
