@@ -221,7 +221,7 @@ class Volume(WMLResource):
         if not self._client.ICP_PLATFORM_SPACES and not self._client.CLOUD_PLATFORM_SPACES:
             raise WMLClientError("Volume APIs are not supported. It is supported only for CP4D 3.5")
 
-        if self._client.ICP_45 and '::' not in name:
+        if (self._client.ICP_45 or self._client.ICP_46) and '::' not in name:
             raise WMLClientError('Invalid name to start volume. Correct volume name format: `<namespace>::<name>`. Retrieve the correct name using `client.volumes.get_name(client.volumes.get_details(volume_id))` command.')
 
         start_url = self._client.service_instance._href_definitions.volume_service_href(name)
